@@ -808,6 +808,8 @@ def old_get_model_max_id_in_db(model):
 
 
 def get_abs_order_type_ls(order_type_ls):
+    if isinstance(order_type_ls, str):
+        order_type_ls = [order_type_ls]
     ret = [re.sub(r'^-', '', field_name) for field_name in order_type_ls]
     return ret
 
@@ -1008,7 +1010,7 @@ def get_MySubQuery(my_model, field_name, function_name, output_field=m.IntegerFi
     - [django文档_1](https://django-orm-cookbook-zh-cn.readthedocs.io/zh_CN/latest/subquery.html)
     - [django文档_2](https://docs.djangoproject.com/zh-hans/4.0/ref/models/expressions/)
 
-    :param my_model: 指定模型, 用以获取模型基本属性`meta`
+    :param my_model: 指定模型, 用以获取模型基本属性`meta`. 若为空, 则认为是annotate字段, 使用默认的field_name.
     :param field_name: 用来进行计算的字段名
     :param function_name: 要在数据库中调用的函数名
     :param output_field: 使用Query计算后, 输出的字段类型
@@ -1022,6 +1024,7 @@ def get_MySubQuery(my_model, field_name, function_name, output_field=m.IntegerFi
     db_column_names = [field.db_column if field.db_column else field.name for field in meta.fields]
     field_dc = dict(zip(field_names, db_column_names))
     db_column_name = field_dc.get(field_name)  # 获取字段在db中的列名
+    db_column_name = db_column_name if db_column_name else field_name       # 没有的话, 就用默认field_name
 
     alias = 'tmp' if not alias else alias
     my_template = f"(SELECT {function_name}({db_column_name}) FROM (%(subquery)s) {alias})"
@@ -1029,7 +1032,7 @@ def get_MySubQuery(my_model, field_name, function_name, output_field=m.IntegerFi
 
     class MySubQuery(m.Subquery):
         template = my_template
-        output_field = my_output_field()
+        output_field = my_output_field() if isinstance(my_output_field, type) else my_output_field
 
     return MySubQuery
 
